@@ -1,11 +1,11 @@
 __author__ = "Francisco Munoz,Aldo Romero,Sobhit Singh,Uthpala Herath,Pedram Tavadze,Eric Bousquet,Xu He"
 __copyright__ = "Copyright 2020"
-__version__ = "5.1.5"
+__version__ = "5.2.1"
 __email__ = (
     "fvmunoz@gmail.com/alromero@mail.wvu.edu/ukh0001@mix.wvu.edu/petavazohi@mix.wvu.edu"
 )
 __status__ = "Development"
-__date__ = "Mar 8th, 2020"
+__date__ = "May 11th, 2020"
 
 # Copyright (C) 2019 Francisco Munoz,Aldo Romero,Sobhit Singh,Uthpala Herath,Pedram Tavadze,Eric Bousquet,Xu He
 #
@@ -25,39 +25,36 @@ __date__ = "Mar 8th, 2020"
 # along with pyprocar.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import sys
-import numpy as np
-import re
 import logging
-import matplotlib.pyplot as plt
-import seekpath
+import re
+import sys
+
 import ase
-import skimage
+import matplotlib.pyplot as plt
+import numpy as np
 import pyfiglet
-
-from pyprocar.utilsprocar import UtilsProcar
-from pyprocar.procarparser import ProcarParser
-from pyprocar.procarplot import ProcarPlot
-from pyprocar.procarfilefilter import ProcarFileFilter
-from pyprocar.procarselect import ProcarSelect
-from pyprocar.fermisurface import FermiSurface
-from pyprocar.procarsymmetry import ProcarSymmetry
-
-# ELK
-from pyprocar.elkparser import ElkParser
-
+import seekpath
+import skimage
 # Abinit
 from pyprocar.abinitparser import AbinitParser
-
+# ELK
+from pyprocar.elkparser import ElkParser
+from pyprocar.fermisurface import FermiSurface
+from pyprocar.procarfilefilter import ProcarFileFilter
+from pyprocar.procarparser import ProcarParser
+from pyprocar.procarplot import ProcarPlot
+from pyprocar.procarselect import ProcarSelect
+from pyprocar.procarsymmetry import ProcarSymmetry
+from pyprocar.utilsprocar import UtilsProcar
 
 from .scriptBandsplot import bandsplot
 from .scriptCat import cat
 from .scriptFermi2D import fermi2D
 from .scriptFermi3D import fermi3D
 from .scriptFilter import filter
-from .scriptRepair import repair
-from .scriptVector import Vector
 from .scriptKmesh2D import generate2dkmesh
 from .scriptKpath import kpath
+from .scriptRepair import repair
 from .scriptUnfold import unfold
+from .scriptVector import Vector
 from .splash import welcome
